@@ -14,10 +14,13 @@ from ..utils import validate_title
 
 class Manhuadb(MangaApi):
 
-    source_url = config.get('source2url')['manhuadb']
+    source = 'manhuadb'
+    source_url = config.get('source2url')[source]
 
     session = copy.deepcopy(MangaApi.session)
     session.headers.update({"referer": source_url})
+    if config.get("auto_proxy"):
+        MangaApi.auto_set_proxy(source)
 
 
     @classmethod
